@@ -265,7 +265,7 @@ class BGLDataset(LogDataset):
 
         self.logs = pd.read_csv(output_dir + 'processed_logs.log_structured.csv')
         self.templates = pd.read_csv(output_dir + 'processed_logs.log_templates.csv')
-        self.logs['Time'] = pd.to_datetime(self.logs['Time'], format='%Y-%m-%d-%H.%M.%S.%f')
+        self.logs['Time'] = pd.to_datetime(self.logs['Time'], format='%Y-%m-%d %H:%M:%S.%f')
         self.logs.sort_values(['Time'])
 
         anomalous_event_ids_dict = {k: 0 for k in list(self.logs[self.logs['Label'] != '-']['EventId'].unique())}
