@@ -184,7 +184,7 @@ def create_one_hot_map_value(all_event_ids, event_id_fill):
 def create_networkx_graph(graph_dict: dict, positional_embeddings: dict, anomalous_logs: list, all_event_ids: list):
     nodes = set()
     edges_list = []
-    graph = nx.DiGraph()
+    graph = nx.MultiDiGraph()
     for start, edges in graph_dict.items():
         nodes.add(start)
         for end, weight in edges.items():
